__author__ = "Alex DeLorenzo"
from setuptools import setup
from pathlib import Path


NAME = "onhold"
VERSION = "0.3.9"
LICENSE = "AGPL-3.0"

DESC = "🔊 Play music while and after jobs complete"

REQUIREMENTS = \
  Path('requirements.txt') \
    .read_text() \
    .split('\n')

README = Path('README.md').read_text()

ENTRY_POINTS = {
  "console_scripts":
    [f"{NAME} = {NAME}.during:cmd",
      f"ding = {NAME}.after:cmd"]
}

setup(
      name=NAME,
      version=VERSION,
      description=DESC,
      long_description=README,
      long_description_content_type="text/markdown",
      url="https://alexdelorenzo.dev",
      author=__author__,
      license=LICENSE,
      packages=[NAME],
      zip_safe=False,
      install_requires=REQUIREMENTS,
      entry_points=ENTRY_POINTS,
      python_requires='>=3.6',
      include_package_data=True,
)



from typing import Optional, ContextManager
from sys import stdin, stdout, exit, stderr
from pathlib import Path
from contextlib import contextmanager
from os import environ
from platform import platform

from play_sounds import DEFAULT_SONG
import click



RC_OK = 0
RC_ENV_VAR = 1
ENV_VAR = 'ONHOLD'
BLOCK_WHILE_PLAYING = True


#def get_assets_dir() -> Path:
  #return Path(__file__).parent / 'assets'


#DEFAULT_ASSETS = get_assets_dir()
#DEFAULT_SONG = DEFAULT_ASSETS / 'song.mp3'
#DEFAULT_SOUND = DEFAULT_ASSETS / 'ding.ogg'

PLATFORM = platform().lower()


def is_pipeline() -> bool:
  return not stdin.isatty()


def dumb_pipe():
  for line in stdin.buffer:
    stdout.buffer.write(line)
    stdout.buffer.flush()


@contextmanager
def using_path(
  sound_path: Optional[str],
  warn: bool,
  default: Optional[Path] = DEFAULT_SONG,
  env_var: str = ENV_VAR,
) -> ContextManager[Path]:
  path = default

  if sound_path:
    path = Path(str(sound_path))

  elif env_var in environ:
    path = Path(environ[env_var])

  elif warn:
    stderr.write(f"Please set ${env_var} or use the -s flag.\n")

  yield path

  if path:
    exit(RC_OK)

  else:
    exit(RC_ENV_VAR)



from typing import Optional
from sys import exit, stderr
from pathlib import Path
from os import environ

from .base import dumb_pipe, using_path, is_pipeline, \
  RC_ENV_VAR, RC_OK

from play_sounds import play_while_running
import click


ENV_VAR = 'ONHOLD'


def run(file: Optional[Path] = None):
  if not file:
    dumb_pipe()
    return

  with play_while_running(file):
    dumb_pipe()


@click.command(help="""Play the specified sound file while data is passed in through standard input and passed through standard output.""")
@click.option('-s', '--sound_path', required=False,
  type=click.Path(exists=True), help="Path to sound to play.")
@click.option('-i', '--ignore', required=False,
  is_flag=True, default=False, help="Suppress warnings.")
def cmd(sound_path: Optional[str], ignore: bool):
  with using_path(sound_path, ignore) as path:
    run(path)


if __name__ == "__main__":
  cmd()
